@@ -1,41 +1,41 @@
-from dataclasses import dataclass
+from enum import Enum
+from typing import Dict, List, Union
 
 from checkov.common.bridgecrew.severities import Severity, BcSeverities, Severities
 from checkov.common.bridgecrew.check_type import CheckType
 
 
-@dataclass
-class CodeCategoryType:
+class CodeCategoryType(str, Enum):
     IAC = "IAC"
-    OPEN_SOURCE = "OPEN_SOURCE"
+    VULNERABILITIES = "VULNERABILITIES"
     SECRETS = "SECRETS"
-    IMAGES = "IMAGES"
-    SUPPLY_CHAIN = "SUPPLY_CHAIN"
+    LICENSES = "LICENSES"
+    BUILD_INTEGRITY = "BUILD_INTEGRITY"
 
 
-CodeCategoryMapping = {
+CodeCategoryMapping: Dict[str, Union[CodeCategoryType, List[CodeCategoryType]]] = {
     CheckType.ANSIBLE: CodeCategoryType.IAC,
-    CheckType.ARGO_WORKFLOWS: CodeCategoryType.SUPPLY_CHAIN,
+    CheckType.ARGO_WORKFLOWS: CodeCategoryType.BUILD_INTEGRITY,
     CheckType.ARM: CodeCategoryType.IAC,
-    CheckType.AZURE_PIPELINES: CodeCategoryType.SUPPLY_CHAIN,
+    CheckType.AZURE_PIPELINES: CodeCategoryType.BUILD_INTEGRITY,
     CheckType.BICEP: CodeCategoryType.IAC,
-    CheckType.BITBUCKET_PIPELINES: CodeCategoryType.SUPPLY_CHAIN,
-    CheckType.CIRCLECI_PIPELINES: CodeCategoryType.SUPPLY_CHAIN,
+    CheckType.BITBUCKET_PIPELINES: CodeCategoryType.BUILD_INTEGRITY,
+    CheckType.CIRCLECI_PIPELINES: CodeCategoryType.BUILD_INTEGRITY,
     CheckType.CLOUDFORMATION: CodeCategoryType.IAC,
     CheckType.DOCKERFILE: CodeCategoryType.IAC,
-    CheckType.GITHUB_CONFIGURATION: CodeCategoryType.SUPPLY_CHAIN,
-    CheckType.GITHUB_ACTIONS: CodeCategoryType.SUPPLY_CHAIN,
-    CheckType.GITLAB_CONFIGURATION: CodeCategoryType.SUPPLY_CHAIN,
-    CheckType.GITLAB_CI: CodeCategoryType.SUPPLY_CHAIN,
-    CheckType.BITBUCKET_CONFIGURATION: CodeCategoryType.SUPPLY_CHAIN,
+    CheckType.GITHUB_CONFIGURATION: CodeCategoryType.BUILD_INTEGRITY,
+    CheckType.GITHUB_ACTIONS: CodeCategoryType.BUILD_INTEGRITY,
+    CheckType.GITLAB_CONFIGURATION: CodeCategoryType.BUILD_INTEGRITY,
+    CheckType.GITLAB_CI: CodeCategoryType.BUILD_INTEGRITY,
+    CheckType.BITBUCKET_CONFIGURATION: CodeCategoryType.BUILD_INTEGRITY,
     CheckType.HELM: CodeCategoryType.IAC,
     CheckType.JSON: CodeCategoryType.IAC,
     CheckType.YAML: CodeCategoryType.IAC,
     CheckType.KUBERNETES: CodeCategoryType.IAC,
     CheckType.KUSTOMIZE: CodeCategoryType.IAC,
     CheckType.OPENAPI: CodeCategoryType.IAC,
-    CheckType.SCA_PACKAGE: CodeCategoryType.OPEN_SOURCE,
-    CheckType.SCA_IMAGE: CodeCategoryType.IMAGES,
+    CheckType.SCA_PACKAGE: [CodeCategoryType.LICENSES, CodeCategoryType.VULNERABILITIES],
+    CheckType.SCA_IMAGE: [CodeCategoryType.LICENSES, CodeCategoryType.VULNERABILITIES],
     CheckType.SECRETS: CodeCategoryType.SECRETS,
     CheckType.SERVERLESS: CodeCategoryType.IAC,
     CheckType.TERRAFORM: CodeCategoryType.IAC,
