@@ -10,7 +10,7 @@ from typing import TYPE_CHECKING, Any, List
 from checkov.common.bridgecrew.integration_features.base_integration_feature import BaseIntegrationFeature
 from checkov.common.bridgecrew.platform_integration import bc_integration
 from checkov.common.bridgecrew.severities import Severities
-from checkov.common.checks_infra.checks_parser import NXGraphCheckParser
+from checkov.common.checks_infra.checks_parser import GraphCheckParser
 from checkov.common.checks_infra.registry import Registry, get_graph_checks_registry
 
 if TYPE_CHECKING:
@@ -26,7 +26,7 @@ CFN_RESOURCE_TYPE_IDENTIFIER = re.compile(r"^[a-zA-Z0-9]+::[a-zA-Z0-9]+::[a-zA-Z
 class CustomPoliciesIntegration(BaseIntegrationFeature):
     def __init__(self, bc_integration: BcPlatformIntegration) -> None:
         super().__init__(bc_integration=bc_integration, order=1)  # must be after policy metadata and before suppression integration
-        self.platform_policy_parser = NXGraphCheckParser()
+        self.platform_policy_parser = GraphCheckParser()
         self.policies_url = f"{self.bc_integration.api_url}/api/v1/policies/table/data"
         self.bc_cloned_checks: dict[str, list[dict[str, Any]]] = defaultdict(list)
         self.policy_level_suppression: List[str] = []
@@ -121,5 +121,9 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
         # not used
         pass
 
+    def post_scan(self, merged_reports: list[Report]) -> None:
+        # not used
+        pass
+
 
 integration = CustomPoliciesIntegration(bc_integration)
