@@ -49,7 +49,8 @@ class RepoConfigIntegration(BaseIntegrationFeature):
             logging.debug("Scanning without applying scanning configs from the platform.", exc_info=True)
 
     @staticmethod
-    def _get_code_category_object(code_category_config: dict[str, Any], code_category_type: str) -> CodeCategoryConfiguration | None:
+    def _get_code_category_object(code_category_config: dict[str, Any],
+                                  code_category_type: str) -> CodeCategoryConfiguration | None:
         if code_category_type not in code_category_config:
             return None
         soft_fail_threshold = Severities[code_category_config[code_category_type]['softFailThreshold']]
@@ -106,11 +107,13 @@ class RepoConfigIntegration(BaseIntegrationFeature):
             logging.info('Found exactly one matching enforcement rule for the specified repo')
             self.enforcement_rule = matched_rules[0]
 
-        logging.debug('Selected the following enforcement rule (it will not be applied unless --use-enforcement-rules is specified):')
+        logging.debug(
+            'Selected the following enforcement rule (it will not be applied unless --use-enforcement-rules is specified):')
         logging.debug(json.dumps(self.enforcement_rule, indent=2))
 
-        for code_category_type in [value for attr, value in CodeCategoryType.__dict__.items() if not attr.startswith("__")]:
-            config = RepoConfigIntegration._get_code_category_object(self.enforcement_rule['codeCategories'], code_category_type)
+        for code_category_type in [e.value for e in CodeCategoryType]:
+            config = RepoConfigIntegration._get_code_category_object(self.enforcement_rule['codeCategories'],
+                                                                     code_category_type)
             if config:
                 self.code_category_configs[code_category_type] = config
 
