@@ -15,8 +15,8 @@ class BillingPlan(str, Enum):
 
 
 SubscriptionCategoryMapping = {
-    CustomerSubscription.IAC: (CodeCategoryType.IAC, CodeCategoryType.SUPPLY_CHAIN),
-    CustomerSubscription.SCA: (CodeCategoryType.OPEN_SOURCE, CodeCategoryType.IMAGES),
+    CustomerSubscription.IAC: (CodeCategoryType.IAC, CodeCategoryType.BUILD_INTEGRITY),
+    CustomerSubscription.SCA: (CodeCategoryType.LICENSES, CodeCategoryType.VULNERABILITIES),
     CustomerSubscription.SECRETS: (CodeCategoryType.SECRETS,)
 }
 
@@ -26,4 +26,4 @@ for sub, cats in SubscriptionCategoryMapping.items():
         CategoryToSubscriptionMapping[cat] = sub
 
 
-open_source_categories = [CodeCategoryType.IAC, CodeCategoryType.SECRETS, CodeCategoryType.SUPPLY_CHAIN]
+open_source_categories = [CodeCategoryType.IAC, CodeCategoryType.SECRETS, CodeCategoryType.BUILD_INTEGRITY]
