@@ -9,7 +9,7 @@ from checkov.common.bridgecrew.integration_features.features.policy_metadata_int
     integration as metadata_integration,
 )
 from checkov.common.bridgecrew.platform_integration import bc_integration
-from checkov.common.bridgecrew.severities import Severities
+from checkov.common.bridgecrew.severities import Severities, Severity
 from checkov.common.models.enums import CheckResult, ScanDataFormat
 from checkov.common.output.extra_resource import ExtraResource
 from checkov.common.output.record import Record, DEFAULT_SEVERITY, SCA_PACKAGE_SCAN_CHECK_NAME, SCA_LICENSE_CHECK_NAME
@@ -21,6 +21,7 @@ from checkov.common.sca.commons import (
     UNFIXABLE_VERSION,
     get_package_type,
     normalize_twistcli_language,
+    get_registry_url,
 )
 from checkov.common.util.http_utils import request_wrapper
 from checkov.runner_filter import RunnerFilter
@@ -38,8 +39,9 @@ def create_report_license_record(
         file_abs_path: str,
         check_class: str,
         licenses_status: _LicenseStatus,
-        package_registry: str,
+        package: dict[str, Any],
         sca_details: SCADetails | None = None,
+        severity: Severity | None = None
 ) -> Record:
     package_name = licenses_status["package_name"]
     package_version = licenses_status["package_version"]
@@ -60,7 +62,8 @@ def create_report_license_record(
     details = {
         "package_name": package_name,
         "package_version": package_version,
-        "package_registry": package_registry,
+        "package_registry": get_registry_url(package),
+        "is_private_registry": package.get("isPrivateRegistry", False),
         "license": licenses_status["license"],
         "status": status,
         "policy": policy,
@@ -81,6 +84,7 @@ def create_report_license_record(
         file_abs_path=file_abs_path,
         short_description=f"License {licenses_status['license']} - {package_name}: {package_version}",
         vulnerability_details=details,
+        severity=severity
     )
     return record
 
@@ -119,7 +123,7 @@ def create_report_cve_record(
         check_class: str,
         vulnerability_details: dict[str, Any],
         licenses: str,
-        package_registry: str,
+        package: dict[str, Any],
         root_package_version: str | None = None,
         root_package_name: str | None = None,
         root_package_fixed_version: str | None = None,
@@ -160,7 +164,8 @@ def create_report_cve_record(
         "severity": severity,
         "package_name": package_name,
         "package_version": package_version,
-        "package_registry": package_registry,
+        "package_registry": get_registry_url(package),
+        "is_private_registry": package.get("isPrivateRegistry", False),
         "package_type": package_type,
         "link": vulnerability_details.get("link"),
         "cvss": vulnerability_details.get("cvss"),
@@ -224,20 +229,22 @@ def _add_to_report_licenses_statuses(
         licenses_per_package_map[package_alias].append(license)
 
         policy = license_status["policy"]
+        severity = metadata_integration.get_severity(policy)
 
         license_record = create_report_license_record(
             rootless_file_path=rootless_file_path,
             file_abs_path=scanned_file_path,
             check_class=check_class or "",
             licenses_status=license_status,
-            package_registry=packages_map.get(package_alias, {}).get("registry", ""),
+            package=packages_map.get(package_alias, {}),
             sca_details=sca_details,
+            severity=severity
         )
 
         if not runner_filter.should_run_check(
                 check_id=policy,
                 bc_check_id=policy,
-                severity=metadata_integration.get_severity(policy),
+                severity=severity,
                 report_type=report_type,
         ):
             if runner_filter.checks:
@@ -369,7 +376,7 @@ def add_cve_record_to_report(vulnerability_details: dict[str, Any], package_name
         check_class=check_class or "",
         vulnerability_details=vulnerability_details,
         licenses=format_licenses_to_string(licenses_per_package_map[package_alias]),
-        package_registry=packages_map.get(package_alias, {}).get("registry", ""),
+        package=packages_map.get(package_alias, {}),
         runner_filter=runner_filter,
         sca_details=sca_details,
         scan_data_format=scan_data_format,
@@ -436,7 +443,7 @@ def add_extra_resources_to_report(report: Report, scanned_file_path: str, rootle
                                   package: dict[str, Any], package_alias: str,
                                   licenses_per_package_map: dict[str, list[str]],
                                   sca_details: Optional[SCADetails]) -> None:
-    package_name, package_version, package_registry = package["name"], package["version"], package.get("registry", "")
+    package_name, package_version = package["name"], package["version"]
     report.extra_resources.add(
         ExtraResource(
             file_abs_path=scanned_file_path,
@@ -445,7 +452,8 @@ def add_extra_resources_to_report(report: Report, scanned_file_path: str, rootle
             vulnerability_details={
                 "package_name": package_name,
                 "package_version": package_version,
-                "package_registry": package_registry,
+                "package_registry": get_registry_url(package),
+                "is_private_registry": package.get("isPrivateRegistry", False),
                 "licenses": format_licenses_to_string(
                     licenses_per_package_map[package_alias]),
                 "package_type": get_package_type(package_name, package_version, sca_details),
