@@ -27,4 +27,8 @@ MAX_IAC_FILE_SIZE = int(os.getenv('CHECKOV_MAX_IAC_FILE_SIZE', '50_000_000'))  #
 
 CHECKOV_RUN_SCA_PACKAGE_SCAN_V2 = os.getenv('CHECKOV_RUN_SCA_PACKAGE_SCAN_V2', 'true').lower() == 'true'
 
+# CHECKOV_DISPLAY_REGISTRY_URL is temporary const and will be removed after getting registry-urls will become fully
+# supported from the platform
+CHECKOV_DISPLAY_REGISTRY_URL = os.getenv('CHECKOV_DISPLAY_REGISTRY_URL', 'false').lower() == 'true'
+
 RESOURCE_ATTRIBUTES_TO_OMIT_UNIVERSAL_MASK = '*'
