@@ -64,7 +64,7 @@ class ExtArgumentParser(configargparse.ArgumentParser):
         return r.getvalue()
 
     def write_config_file(
-        self, parsed_namespace: argparse.Namespace, output_file_paths: list[str], exit_after: bool = False
+            self, parsed_namespace: argparse.Namespace, output_file_paths: list[str], exit_after: bool = False
     ) -> None:
         """
         Write the given settings to output files. Overrides write_config_file from the class ArgumentParser for
@@ -137,16 +137,16 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             "--file",
             action="append",
             help="File to scan (can not be used together with --directory). With this option, Checkov will attempt "
-            'to filter the runners based on the file type. For example, if you specify a ".tf" file, only the '
-            "terraform and secrets frameworks will be included. You can further limit this (e.g., skip secrets) "
-            "by using the --skip-framework argument.",
+                 'to filter the runners based on the file type. For example, if you specify a ".tf" file, only the '
+                 "terraform and secrets frameworks will be included. You can further limit this (e.g., skip secrets) "
+                 "by using the --skip-framework argument.",
         )
         self.add(
             "--skip-path",
             action="append",
             help="Path (file or directory) to skip, using regular expression logic, relative to current "
-            'working directory. Word boundaries are not implicit; i.e., specifying "dir1" will skip any '
-            'directory or subdirectory named "dir1". Ignored with -f. Can be specified multiple times.',
+                 'working directory. Word boundaries are not implicit; i.e., specifying "dir1" will skip any '
+                 'directory or subdirectory named "dir1". Ignored with -f. Can be specified multiple times.',
         )
         self.add(
             "--external-checks-dir",
@@ -157,7 +157,7 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             "--external-checks-git",
             action="append",
             help="Github url of external checks to be added. \n you can specify a subdirectory after a "
-            "double-slash //. \n cannot be used together with --external-checks-dir",
+                 "double-slash //. \n cannot be used together with --external-checks-dir",
         )
         self.add(
             "-l",
@@ -177,9 +177,9 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             "--output-file-path",
             default=None,
             help="Name of the output folder to save the chosen output formats. "
-            "Advanced usage: "
-            "By using -o cli -o junitxml --output-file-path console,results.xml the CLI output will be printed "
-            "to the console and the JunitXML output to the file results.xml.",
+                 "Advanced usage: "
+                 "By using -o cli -o junitxml --output-file-path console,results.xml the CLI output will be printed "
+                 "to the console and the JunitXML output to the file results.xml.",
         )
         self.add(
             "--output-bc-ids",
@@ -190,11 +190,11 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             "--include-all-checkov-policies",
             action="store_true",
             help="When running with an API key, Checkov will omit any policies that do not exist "
-            "in the Bridgecrew or Prisma Cloud platform, except for local custom policies loaded with the "
-            "--external-check flags. Use this key to include policies that only exist in Checkov in the scan. "
-            "Note that this will make the local CLI results different from the results you see in the "
-            "platform. Has no effect if you are not using an API key. Use the --check option to explicitly "
-            "include checks by ID even if they are not in the platform, without using this flag.",
+                 "in the Bridgecrew or Prisma Cloud platform, except for local custom policies loaded with the "
+                 "--external-check flags. Use this key to include policies that only exist in Checkov in the scan. "
+                 "Note that this will make the local CLI results different from the results you see in the "
+                 "platform. Has no effect if you are not using an API key. Use the --check option to explicitly "
+                 "include checks by ID even if they are not in the platform, without using this flag.",
         )
         self.add(
             "--quiet",
@@ -219,9 +219,9 @@ class ExtArgumentParser(configargparse.ArgumentParser):
         self.add(
             "--skip-framework",
             help="Filter scan to skip specific infrastructure as code frameworks."
-            "This will be included automatically for some frameworks if system dependencies "
-            "are missing. Add multiple frameworks using spaces. For example, "
-            "--skip-framework terraform sca_package.",
+                 "This will be included automatically for some frameworks if system dependencies "
+                 "are missing. Add multiple frameworks using spaces. For example, "
+                 "--skip-framework terraform sca_package.",
             choices=checkov_runners,
             default=None,
             nargs="+",
@@ -230,15 +230,15 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             "-c",
             "--check",
             help="Checks to run; any other checks will be skipped. Enter one or more items separated by commas. "
-            "Each item may be either a Checkov check ID (CKV_AWS_123), a BC check ID (BC_AWS_GENERAL_123), or "
-            "a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a severity, then all checks equal to or "
-            "above the lowest severity in the list will be included. This option can be combined with "
-            "--skip-check. If it is, then the logic is to first take all checks that match this list, and then "
-            "remove all checks that match the skip list. For example, if you use --check CKV_123 and "
-            "--skip-check LOW, then CKV_123 will not run if it is a LOW severity. Similarly, if you use "
-            "--check CKV_789 --skip-check MEDIUM, then CKV_789 will run if it is a HIGH severity. If you use a "
-            "check ID here along with an API key, and the check is not part of the BC / PC platform, then the "
-            "check will still be run (see --include-all-checkov-policies for more info).",
+                 "Each item may be either a Checkov check ID (CKV_AWS_123), a BC check ID (BC_AWS_GENERAL_123), or "
+                 "a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a severity, then all checks equal to or "
+                 "above the lowest severity in the list will be included. This option can be combined with "
+                 "--skip-check. If it is, then the logic is to first take all checks that match this list, and then "
+                 "remove all checks that match the skip list. For example, if you use --check CKV_123 and "
+                 "--skip-check LOW, then CKV_123 will not run if it is a LOW severity. Similarly, if you use "
+                 "--check CKV_789 --skip-check MEDIUM, then CKV_789 will run if it is a HIGH severity. If you use a "
+                 "check ID here along with an API key, and the check is not part of the BC / PC platform, then the "
+                 "check will still be run (see --include-all-checkov-policies for more info).",
             action="append",
             default=None,
             env_var="CKV_CHECK",
@@ -246,13 +246,13 @@ class ExtArgumentParser(configargparse.ArgumentParser):
         self.add(
             "--skip-check",
             help="Checks to skip; any other checks will not be run. Enter one or more items separated by commas. "
-            "Each item may be either a Checkov check ID (CKV_AWS_123), a BC check ID (BC_AWS_GENERAL_123), or "
-            "a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a severity, then all checks equal to or "
-            "below the highest severity in the list will be skipped. This option can be combined with --check. "
-            "If it is, priority is given to checks explicitly listed by ID or wildcard over checks listed by "
-            "severity. For example, if you use --skip-check CKV_123 and --check HIGH, then CKV_123 will be "
-            "skipped even if it is a HIGH severity. In the case of a tie (e.g., --check MEDIUM and "
-            "--skip-check HIGH for a medium severity check), then the check will be skipped.",
+                 "Each item may be either a Checkov check ID (CKV_AWS_123), a BC check ID (BC_AWS_GENERAL_123), or "
+                 "a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a severity, then all checks equal to or "
+                 "below the highest severity in the list will be skipped. This option can be combined with --check. "
+                 "If it is, priority is given to checks explicitly listed by ID or wildcard over checks listed by "
+                 "severity. For example, if you use --skip-check CKV_123 and --check HIGH, then CKV_123 will be "
+                 "skipped even if it is a HIGH severity. In the case of a tie (e.g., --check MEDIUM and "
+                 "--skip-check HIGH for a medium severity check), then the check will be skipped.",
             action="append",
             default=None,
             env_var="CKV_SKIP_CHECK",
@@ -261,39 +261,39 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             "--run-all-external-checks",
             action="store_true",
             help="Run all external checks (loaded via --external-checks options) even if the checks are not present "
-            "in the --check list. This allows you to always ensure that new checks present in the external "
-            "source are used. If an external check is included in --skip-check, it will still be skipped.",
+                 "in the --check list. This allows you to always ensure that new checks present in the external "
+                 "source are used. If an external check is included in --skip-check, it will still be skipped.",
         )
         self.add(
             "-s",
             "--soft-fail",
             help="Runs checks but always returns a 0 exit code. Using either --soft-fail-on and / or --hard-fail-on "
-            "overrides this option, except for the case when a result does not match either of the soft fail "
-            "or hard fail criteria, in which case this flag determines the result.",
+                 "overrides this option, except for the case when a result does not match either of the soft fail "
+                 "or hard fail criteria, in which case this flag determines the result.",
             action="store_true",
         )
         self.add(
             "--soft-fail-on",
             help="Exits with a 0 exit code if only the specified items fail. Enter one or more items "
-            "separated by commas. Each item may be either a Checkov check ID (CKV_AWS_123), a BC "
-            "check ID (BC_AWS_GENERAL_123), or a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use "
-            "a severity, then any severity equal to or less than the highest severity in the list "
-            "will result in a soft fail. This option may be used with --hard-fail-on, using the same "
-            "priority logic described in --check and --skip-check options above, with --hard-fail-on "
-            "taking precedence in a tie. If a given result does not meet the --soft-fail-on nor "
-            "the --hard-fail-on criteria, then the default is to hard fail",
+                 "separated by commas. Each item may be either a Checkov check ID (CKV_AWS_123), a BC "
+                 "check ID (BC_AWS_GENERAL_123), or a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use "
+                 "a severity, then any severity equal to or less than the highest severity in the list "
+                 "will result in a soft fail. This option may be used with --hard-fail-on, using the same "
+                 "priority logic described in --check and --skip-check options above, with --hard-fail-on "
+                 "taking precedence in a tie. If a given result does not meet the --soft-fail-on nor "
+                 "the --hard-fail-on criteria, then the default is to hard fail",
             action="append",
             default=None,
         )
         self.add(
             "--hard-fail-on",
             help="Exits with a non-zero exit code for specified checks. Enter one or more items "
-            "separated by commas. Each item may be either a Checkov check ID (CKV_AWS_123), a BC "
-            "check ID (BC_AWS_GENERAL_123), or a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a "
-            "severity, then any severity equal to or greater than the lowest severity in the list will "
-            "result in a hard fail. This option can be used with --soft-fail-on, using the same "
-            "priority logic described in --check and --skip-check options above, with --hard-fail-on "
-            "taking precedence in a tie.",
+                 "separated by commas. Each item may be either a Checkov check ID (CKV_AWS_123), a BC "
+                 "check ID (BC_AWS_GENERAL_123), or a severity (LOW, MEDIUM, HIGH, CRITICAL). If you use a "
+                 "severity, then any severity equal to or greater than the lowest severity in the list will "
+                 "result in a hard fail. This option can be used with --soft-fail-on, using the same "
+                 "priority logic described in --check and --skip-check options above, with --hard-fail-on "
+                 "taking precedence in a tie.",
             action="append",
             default=None,
         )
@@ -308,7 +308,7 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             env_var="PRISMA_API_URL",
             default=None,
             help="The Prisma Cloud API URL (see: https://prisma.pan.dev/api/cloud/api-urls). "
-            "Requires --bc-api-key to be a Prisma Cloud Access Key in the following format: <access_key_id>::<secret_key>",
+                 "Requires --bc-api-key to be a Prisma Cloud Access Key in the following format: <access_key_id>::<secret_key>",
         )
         self.add(
             "--docker-image",
@@ -332,23 +332,23 @@ class ExtArgumentParser(configargparse.ArgumentParser):
         self.add(
             "--skip-download",
             help="Do not download any data from Bridgecrew. This will omit doc links, severities, etc., as well as "
-            "custom policies and suppressions if using an API token. Note: it will prevent BC platform IDs from "
-            "being available in Checkov.",
+                 "custom policies and suppressions if using an API token. Note: it will prevent BC platform IDs from "
+                 "being available in Checkov.",
             action="store_true",
         )
         self.add(
             "--use-enforcement-rules",
             action="store_true",
             help="Use the Enforcement rules configured in the platform for hard / soft fail logic. With this option, "
-            "the enforcement rule matching this repo, or the default rule if there is no match, will determine "
-            "this behavior: any check with a severity below the selected rule's soft-fail threshold will be "
-            "skipped; any check with a severity equal to or greater than the rule's hard-fail threshold will "
-            "be part of the hard-fail list, and any check in between will be part of the soft-fail list. For "
-            "example, if the given enforcement rule has a hard-fail value of HIGH and a soft-fail value of MEDIUM,"
-            "this is the equivalent of using the flags `--skip-check LOW --hard-fail-on HIGH`. You can use --check, "
-            "--skip-check, --soft-fail, --soft-fail-on, or --hard-fail-on to override portions of an enforcement rule. "
-            "Note, however, that the logic of applying the --check list and then the --skip-check list (as described "
-            "above under --check) still applies here. Requires a BC or PC platform API key.",
+                 "the enforcement rule matching this repo, or the default rule if there is no match, will determine "
+                 "this behavior: any check with a severity below the selected rule's soft-fail threshold will be "
+                 "skipped; any check with a severity equal to or greater than the rule's hard-fail threshold will "
+                 "be part of the hard-fail list, and any check in between will be part of the soft-fail list. For "
+                 "example, if the given enforcement rule has a hard-fail value of HIGH and a soft-fail value of MEDIUM,"
+                 "this is the equivalent of using the flags `--skip-check LOW --hard-fail-on HIGH`. You can use --check, "
+                 "--skip-check, --soft-fail, --soft-fail-on, or --hard-fail-on to override portions of an enforcement rule. "
+                 "Note, however, that the logic of applying the --check list and then the --skip-check list (as described "
+                 "above under --check) still applies here. Requires a BC or PC platform API key.",
         )
         self.add(
             "--no-guide",
@@ -381,9 +381,9 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             "--var-file",
             action="append",
             help="Variable files to load in addition to the default files (see "
-            "https://www.terraform.io/docs/language/values/variables.html#variable-definitions-tfvars-files)."
-            "Currently only supported for source Terraform (.tf file), and Helm chart scans."
-            "Requires using --directory, not --file.",
+                 "https://www.terraform.io/docs/language/values/variables.html#variable-definitions-tfvars-files)."
+                 "Currently only supported for source Terraform (.tf file), and Helm chart scans."
+                 "Requires using --directory, not --file.",
         )
         self.add(
             "--external-modules-download-path",
@@ -421,21 +421,21 @@ class ExtArgumentParser(configargparse.ArgumentParser):
         self.add(
             "--show-config",
             help="prints all args and config settings and where they came from "
-            "(eg. commandline, config file, environment variable or default)",
+                 "(eg. commandline, config file, environment variable or default)",
             action="store_true",
             default=None,
         )
         self.add(
             "--create-baseline",
             help="Alongside outputting the findings, save all results to .checkov.baseline file"
-            " so future runs will not re-flag the same noise. Works only with `--directory` flag",
+                 " so future runs will not re-flag the same noise. Works only with `--directory` flag",
             action="store_true",
             default=False,
         )
         self.add(
             "--baseline",
             help="Use a .checkov.baseline file to compare current results with a known baseline. "
-            "Report will include only failed checks that are new with respect to the provided baseline",
+                 "Report will include only failed checks that are new with respect to the provided baseline",
             default=None,
         )
         self.add(
@@ -447,15 +447,15 @@ class ExtArgumentParser(configargparse.ArgumentParser):
         self.add(
             "--skip-cve-package",
             help="filter scan to run on all packages but a specific package identifier (denylist), You can "
-            "specify this argument multiple times to skip multiple packages",
+                 "specify this argument multiple times to skip multiple packages",
             action="append",
             default=None,
         )
         self.add(
             "--policy-metadata-filter",
             help="comma separated key:value string to filter policies based on Prisma Cloud policy metadata. "
-            "See https://prisma.pan.dev/api/cloud/cspm/policy#operation/get-policy-filters-and-options for "
-            "information on allowed filters. Format: policy.label=test,cloud.type=aws ",
+                 "See https://prisma.pan.dev/api/cloud/cspm/policy#operation/get-policy-filters-and-options for "
+                 "information on allowed filters. Format: policy.label=test,cloud.type=aws ",
             default=None,
         )
         self.add(
@@ -484,7 +484,7 @@ class ExtArgumentParser(configargparse.ArgumentParser):
             default="top",
             choices=SUMMARY_POSITIONS,
             help="Chose whether the summary will be appended on top (before the checks results) or on bottom "
-            "(after check results), default is on top.",
+                 "(after check results), default is on top.",
         )
         self.add(
             "--skip-resources-without-violations",
@@ -514,3 +514,15 @@ class ExtArgumentParser(configargparse.ArgumentParser):
                  "Notice: one entry can contain several variables, seperated with a comma. For example:"
                  "<resource_type>:<variable1>,<variable2> OR <variable1>,<variable2>"
         )
+        self.add(
+            "--scan-secrets-history",
+            action="store_true",
+            default=False,
+            help="will scan the history of commits for secrets"
+        )
+        self.add(
+            "--secrets-history-timeout",
+            action="store",
+            default='12h',
+            help="maximum time to stop the scan "
+        )
