@@ -1,6 +1,6 @@
 import logging
 import os
-
+from io import StringIO
 
 LOG_LEVEL = os.environ.get('LOG_LEVEL', 'WARNING').upper()
 logging.basicConfig(level=LOG_LEVEL)
@@ -14,3 +14,8 @@ logging.getLogger("urllib3").setLevel(logging.ERROR)
 logging.getLogger("urllib3.connectionpool").setLevel(logging.ERROR)
 logging.getLogger("urllib3.connectionpool").propagate = False
 logging.getLogger("urllib3").propagate = False
+log_stream = StringIO()
+stream_handler = logging.StreamHandler(stream=log_stream)
+stream_handler.setFormatter(log_formatter)
+stream_handler.setLevel(logging.DEBUG)
+root_logger.addHandler(stream_handler)
