@@ -9,7 +9,7 @@ from checkov.common.sca.commons import should_run_scan
 from checkov.common.sca.output import add_to_report_sca_data
 from checkov.common.typing import _LicenseStatus
 from checkov.common.bridgecrew.platform_integration import bc_integration, FileToPersist
-from checkov.common.models.consts import SCANNABLE_PACKAGE_FILES
+from checkov.common.models.consts import SCANNABLE_PACKAGE_FILES_EXTENSIONS, SCANNABLE_PACKAGE_FILES
 from checkov.common.models.enums import ErrorStatus
 from checkov.common.output.report import Report
 from checkov.common.bridgecrew.check_type import CheckType
@@ -22,7 +22,7 @@ class Runner(BaseRunner[None]):
     check_type = CheckType.SCA_PACKAGE  # noqa: CCE003  # a static attribute
 
     def __init__(self, report_type: str = check_type) -> None:
-        super().__init__(file_names=SCANNABLE_PACKAGE_FILES)
+        super().__init__(file_extensions=SCANNABLE_PACKAGE_FILES_EXTENSIONS, file_names=SCANNABLE_PACKAGE_FILES)
         self._check_class: str | None = None
         self._code_repo_path: Path | None = None
         self.report_type = report_type
@@ -139,7 +139,7 @@ class Runner(BaseRunner[None]):
         try:
             if root_path:
                 for file_path in root_path.glob("**/*"):
-                    if file_path.name in SCANNABLE_PACKAGE_FILES and not any(
+                    if (file_path.name in SCANNABLE_PACKAGE_FILES or file_path.suffix in SCANNABLE_PACKAGE_FILES_EXTENSIONS) and not any(
                             p in file_path.parts for p in excluded_paths) and file_path.name not in excluded_file_names:
                         file_path_str = str(file_path)
                         package_files_to_persist.append(
@@ -152,7 +152,7 @@ class Runner(BaseRunner[None]):
                     if not file_path.exists():
                         logging.warning(f"File {file_path} doesn't exist")
                         continue
-                    if file_path.name in SCANNABLE_PACKAGE_FILES:
+                    if file_path.name in SCANNABLE_PACKAGE_FILES or file_path.suffix in SCANNABLE_PACKAGE_FILES_EXTENSIONS:
                         package_files_to_persist.append(FileToPersist(file, os.path.relpath(file, root_folder)))
 
             logging.info(f"{len(package_files_to_persist)} sca package files found.")
