@@ -2,7 +2,6 @@ import re
 from typing import Dict, List, Any
 
 from checkov.common.models.enums import CheckResult, CheckCategories
-from checkov.common.util.secrets import omit_secret_value_from_line
 from checkov.terraform.checks.provider.base_check import BaseProviderCheck
 from checkov.common.models.consts import bridgecrew_token_pattern
 
@@ -11,8 +10,8 @@ class BridgecrewCredentials(BaseProviderCheck):
     def __init__(self) -> None:
         name = "Ensure no hard coded API token exist in the provider"
         id = "CKV_BCW_1"
-        supported_provider = ["bridgecrew"]
-        categories = [CheckCategories.SECRETS]
+        supported_provider = ("bridgecrew",)
+        categories = (CheckCategories.SECRETS,)
         super().__init__(name=name, id=id, categories=categories, supported_provider=supported_provider)
 
     def scan_provider_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
