@@ -1,3 +1,5 @@
+from typing import List
+
 from checkov.common.models.enums import CheckCategories, CheckResult
 from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 
@@ -13,11 +15,12 @@ class FrontdoorUseWAFMode(BaseResourceCheck):
     def scan_resource_conf(self, conf):
         if 'policy_settings' in conf and conf['policy_settings'][0]:
             policy_settings = conf['policy_settings'][0]
-            self.evaluated_keys = ['policy_settings']
             if 'enabled' in policy_settings and not policy_settings['enabled'][0]:
-                self.evaluated_keys = ['policy_settings/[0]/enabled']
                 return CheckResult.FAILED
         return CheckResult.PASSED
 
+    def get_evaluated_keys(self) -> List[str]:
+        return ["policy_settings/[0]/enable"]
+
 
 check = FrontdoorUseWAFMode()
